==> ovirt-engine-sdk-java-4.4.3.tar.gz: org/ovirt/engine/sdk4/types/FirewallType.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.types;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Describes all firewall types supported by the system.
 */
public enum FirewallType {
    /**
     * FirewallD firewall type.
     * 
     * When a cluster has the firewall type set to `firewalld`, the firewalls of all hosts in the cluster will be configured
     * using `firewalld`. http://www.firewalld.org[FirewallD] replaced IPTables in version 4.2. It simplifies
     * configuration using a command line program and dynamic configuration.
     */
    FIREWALLD("firewalld"),
    /**
     * IPTables firewall type.
     * 
     * When a cluster has the firewall type set to `iptables`, the firewalls of all hosts in the cluster will be configured using
     * `iptables`. `iptables` adds firewall rules to `/etc/sysconfig/iptables` using a special `iptables` syntax. For
     * more information, see the `iptables` manual page.
     * 
     * `iptables` is deprecated in cluster version 4.2 and will be removed in a future cluster version.
     */
    IPTABLES("iptables"),
    ;
    
    private static final Logger log = LoggerFactory.getLogger(FirewallType.class);
    
    private String image;
    
    FirewallType(String image) {
        this.image = image;
    }
    
    public String value() {
        return image;
    }
    
    public static FirewallType fromValue(String value) {
        try {
            return valueOf(value.toUpperCase());
        }
        catch (IllegalArgumentException exception) {
            log.error(
            "The string '" + value + "' isn't a valid value for the 'FirewallType' enumerated type. " +
            "Valid values are 'firewalld' and 'iptables'.",
            exception
            );
            return null;
        }
    }
    
}

==> ovirt-engine-sdk-java-4.4.6.tar.gz: org/ovirt/engine/sdk4/types/FirewallType.java <==
/*
Copyright (c) 2015 Red Hat, Inc.
Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

  http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package org.ovirt.engine.sdk4.types;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

/**
 * Describes all firewall types supported by the system.
 */
public enum FirewallType {
    /**
     * FirewallD firewall type.
     * 
     * When a cluster has the firewall type set to `firewalld`, the firewalls of all hosts in the cluster will be configured
     * using `firewalld`. http://www.firewalld.org[FirewallD] replaced IPTables in version 4.2. It simplifies
     * configuration using a command line program and dynamic configuration.
     */
    FIREWALLD("firewalld"),
    /**
     * IPTables firewall type.
     * 
     * `iptables` is deprecated.
     */
    IPTABLES("iptables"),
    ;
    
    private static final Logger log = LoggerFactory.getLogger(FirewallType.class);
    
    private String image;
    
    FirewallType(String image) {
        this.image = image;
    }
    
    public String value() {
        return image;
    }
    
    public static FirewallType fromValue(String value) {
        try {
            return valueOf(value.toUpperCase());
        }
        catch (IllegalArgumentException exception) {
            log.error(
            "The string '" + value + "' isn't a valid value for the 'FirewallType' enumerated type. " +
            "Valid values are 'firewalld' and 'iptables'.",
            exception
            );
            return null;
        }
    }
    
}
